==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/rsmartsepa.lang.inc.php <==
<?php

/* --------------------------------------------------------------
  rsmartsepa.lang.inc.php 2015-04-24 wem
  German language file for the rsmartsepa payment module
  Smart Payment Solutions GmbH
  http://www.smart-payment-solutions.de/
  Copyright (c) 2015 Smart Payment Solutions GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------
 */

$t_language_text_section_content_array = array
(
    'MODULE_PAYMENT_RSMARTSEPA_TEXT_TITLE' => 'Bezahlen mit dem Smartphone',
    'MODULE_PAYMENT_RSMARTSEPA_TEXT_DESCRIPTION' => 'Bezahlen Sie sicher und einfach mit Ihrem Smartphone. Weitere Informationen zu rSm@rt finden Sie auf unserer Webseite: <a href="http://www.smart-payment-solutions.de/" target="_blank">www.smart-payment-solutions.de</a>',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SYSTEMREQUIREMENTS' => 'Systemanforderungen',
    'MODULE_PAYMENT_RSMARTSEPA_STR_EXISTING' => 'Existiert',
    'MODULE_PAYMENT_RSMARTSEPA_STR_MISSING' => 'Fehlt',
    'MODULE_PAYMENT_RSMARTSEPA_STR_CHECKOUT_MODULETITLE' => 'Bezahlen mit dem Smartphone',
    'MODULE_PAYMENT_RSMARTSEPA_STR_CHECKOUT_DESCRIPTION' => 'Mit rSm@rt bezahlen Sie einfach und sicher in ganz Europa. ' .
                                                            'F&uuml;r die Bezahlung ben&ouml;tigen Sie die rSm@rt App und ein onlinef&auml;higes Girokonto. ' .
                                                            'Die Zahlung wird durch das Scannen/Fotografieren des angezeigten QR-Codes eingeleitet. ' .
                                                            'Weitere Informationen zu rSm@rt finden Sie auf unserer Webseite: <a href="http://www.smart-payment-solutions.de/" target="_blank">www.smart-payment-solutions.de</a>' .
                                                            '<br/><br/>Jetzt die App installieren:',
    'MODULE_PAYMENT_RSMARTSEPA_STR_CHECKOUT_CONFIRMATION' => 'Halten Sie Ihre rSm@rtLITE oder rSm@rtSEPA App bereit. ' .
                                                             'Wenn Sie auf den <b>Bestellen</b> Button klicken, wird ein QR-Code angezeigt, ' .
                                                             'den Sie mit der App scannen und best&auml;tigen m&uuml;ssen.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_ORDERNUMBER' => 'Order Nummer',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SELLER' => 'Verk&auml;ufer',
    'MODULE_PAYMENT_RSMARTSEPA_STR_AMOUNT' => 'Betrag',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SCANTEXT' => 'Starten Sie nun Ihre rSmart-App, dr&uuml;cken Sie bitte auf das Symbol "&Uuml;berweisung" und scannen/fotografieren dann den angezeigten QR-Code',
    'MODULE_PAYMENT_RSMARTSEPA_STR_CANCEL' => 'Abbrechen',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SIMULATEMATCH' => 'Simuliere Erfolg',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SIMULATEFAILURE' => 'Simuliere Fehler',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SIMULATION' => 'Simulation',
    'MODULE_PAYMENT_RSMARTSEPA_STR_ERROR_CREATETRANSACTION' => 'Bezahlung mit rSm@rt fehlgeschlagen!',
    'MODULE_PAYMENT_RSMARTSEPA_STR_REASON' => 'Grund',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYMENTSUCCESS' => 'Bezahlung mit rSm@rt war erfolgreich',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYMENTFAILED' => 'Bezahlung mit rSm@rt ist fehlgeschlagen!',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYMENTCANCELLED' => 'Bezahlung mit rSm@rt wurde abgebrochen!',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PREVIEWLINKTITLE' => 'Vorschau in neuem Browser TAB ohne Javascript Funktionalit&auml;t',
    'MODULE_PAYMENT_RSMARTSEPA_STR_TEMPLATETESTDESCRIPTION' => 'Testen Sie verschiedene Browser Fenstergr&ouml;ssen, um zu sehen, wie sich das Template ver&auml;ndert. Wenn Sie fertig sind, schliessen Sie diese Browser TAB',
    'MODULE_PAYMENT_RSMARTSEPA_STR_TOUCHTEXT1' => 'Falls Sie die rSmartSEPA App installiert haben, bewirkt der Link',
    'MODULE_PAYMENT_RSMARTSEPA_STR_TOUCHTEXT2' => 'den Start dieser App.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_TOUCHTEXT3' => 'Andernfalls wird der Browser versuchen, eine nicht existierende Seite zu &ouml;ffnen.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_TOUCHTEXT4' => 'Wollen Sie diesem Link wirklich folgen?',
    'MODULE_PAYMENT_RSMARTSEPA_STR_INVALID_TERMINALDATA' => 'Ungültige Konfiguration. Grund:',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYSAVEINEUROPE' => 'Realtime, einfach und sicher in ganz Europa bezahlen.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_MATCHFLAGSET' => 'Das MATCH Simulationsflag wurde gesetzt. Der n&auml;chste Pollzyklus wird darauf reagieren.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_FAILUREFLAGSET' => 'Das FEHLER Simulationsflag wurde gesetzt. Der n&auml;chste Pollzyklus wird darauf reagieren.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYMENTINVALIDHASH' => 'Bezahlung mit rSm@rt wurde wegen eines Fehlers abgebrochen!',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYMENTCANCELFAILED' => 'Bezahlvorgang konnte auf dem Server nicht mehr erfolgreich abgebrochen werden!',
    
    'MODULE_PAYMENT_RSMARTSEPA_STATUS_TITLE' => 'rSm@rt',
    'MODULE_PAYMENT_RSMARTSEPA_STATUS_DESC' => 'rSm@rt aktivieren?',
    'MODULE_PAYMENT_RSMARTSEPA_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
    'MODULE_PAYMENT_RSMARTSEPA_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt',
    'MODULE_PAYMENT_RSMARTSEPA_ZONE_TITLE' => 'Bezahlzone',
    'MODULE_PAYMENT_RSMARTSEPA_ZONE_DESC' => 'Wenn Sie eine Zone ausw&auml;hlen, wird diese Zahlungsart nur dort verf&uuml;gbar sein',
    'MODULE_PAYMENT_RSMARTSEPA_ALLOWED_TITLE' => 'Erlaubte Zonen',
    'MODULE_PAYMENT_RSMARTSEPA_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche f&uuml;r dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_ERROR_TITLE' => 'Bestellstatus nach Fehler bei Bezahlung',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_ERROR_DESC' => 'Status der gesetzt werden soll, wenn die Bezahlung mit einem Fehler beendet wird.<br/><b>Empfohlen: "rsmartsepa Fehler"</b>',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_OK_TITLE' => 'Bestellstatus nach erfolgreicher Bezahlung',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_OK_DESC' => 'Status der gesetzt werden soll, wenn die Bezahlung erfolgreich beendet wird.<br/><b>Empfohlen: "rsmartsepa Bezahlt"</b>',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_TEMP_TITLE' => 'Tempor&auml;rer Bestellstatus',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_TEMP_DESC' => 'Dieser Status wird zu Beginn der Bezahlung gesetzt.<br/><b>Empfohlen: "rsmartsepa Offen"</b>',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_URI_TITLE' => '<hr/><u>TERMINAL DATEN</u><br/><br/>Terminal URI',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_URI_DESC' => 'Diesen Wert finden Sie in Ihrem Terminal auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_SELLERID_TITLE' => 'Verk&auml;ufer ID (sellerId)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_SELLERID_DESC' => 'Diesen Wert finden Sie in Ihrem Projekt auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_KEY_TITLE' => 'Verk&auml;ufer Key (key)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_KEY_DESC' => 'Diesen Wert finden Sie in Ihrem Projekt auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_PROVIDERID_TITLE' => 'Provider ID (providerId)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_PROVIDERID_DESC' => 'Diese ID finden Sie in Ihrem Terminal auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_COUNTRYID_TITLE' => 'L&auml;ndercode (countryId)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_COUNTRYID_DESC' => 'Geben Sie hier einen zweistelligen L&auml;ndercode ein. (z.B. de)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_SALESPOINTID_TITLE' => 'Verkaufsstelle (salesPointId)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_SALESPOINTID_DESC' => 'Diesen Wert finden Sie in Ihrem Terminal auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_DESCRIPTION_TITLE' => 'Terminalbeschreibung (description)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_DESCRIPTION_DESC' => 'Diesen Wert finden Sie in Ihrem Terminal auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_SIMULATIONMODE_TITLE' => '<hr/>Simulationsmodus aktivieren ?',
    'MODULE_PAYMENT_RSMARTSEPA_SIMULATIONMODE_DESC' => 'Der Simulationsmodus dient zum Testen ohne Smartphone. WICHTIG: Die Order wird dennoch entsprechend auf Bezahlt, Fehlgeschlagen oder Abgebrochen gesetzt.',
    'MODULE_PAYMENT_RSMARTSEPA_DEBUGMODE_TITLE' => 'Debug Modus',
    'MODULE_PAYMENT_RSMARTSEPA_DEBUGMODE_DESC' => 'Wenn aktiv, wird ein Javascript Debug Overlay im Bezahl Screen angezeigt',
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/rsmartsepa.lang.inc.php <==
<?php

/* --------------------------------------------------------------
  rsmartsepa.lang.inc.php 2015-04-24 wem
  German language file for the rsmartsepa payment module
  Smart Payment Solutions GmbH
  http://www.smart-payment-solutions.de/
  Copyright (c) 2015 Smart Payment Solutions GmbH
  Released under the GNU General Public License (Version 2)
  [http://www.gnu.org/licenses/gpl-2.0.html]
  --------------------------------------------------------------
 */

$t_language_text_section_content_array = array
(
    'MODULE_PAYMENT_RSMARTSEPA_TEXT_TITLE' => 'Bezahlen mit dem Smartphone',
    'MODULE_PAYMENT_RSMARTSEPA_TEXT_DESCRIPTION' => 'Bezahlen Sie sicher und einfach mit Ihrem Smartphone. Weitere Informationen zu rSm@rt finden Sie auf unserer Webseite: <a href="http://www.smart-payment-solutions.de/" target="_blank">www.smart-payment-solutions.de</a>',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SYSTEMREQUIREMENTS' => 'Systemanforderungen',
    'MODULE_PAYMENT_RSMARTSEPA_STR_EXISTING' => 'Existiert',
    'MODULE_PAYMENT_RSMARTSEPA_STR_MISSING' => 'Fehlt',
    'MODULE_PAYMENT_RSMARTSEPA_STR_CHECKOUT_MODULETITLE' => 'Bezahlen mit dem Smartphone',
    'MODULE_PAYMENT_RSMARTSEPA_STR_CHECKOUT_DESCRIPTION' => 'Mit rSm@rt bezahlen Sie einfach und sicher in ganz Europa. ' .
                                                            'F&uuml;r die Bezahlung ben&ouml;tigen Sie die rSm@rt App und ein onlinef&auml;higes Girokonto. ' .
                                                            'Die Zahlung wird durch das Scannen/Fotografieren des angezeigten QR-Codes eingeleitet. ' .
                                                            'Weitere Informationen zu rSm@rt finden Sie auf unserer Webseite: <a href="http://www.smart-payment-solutions.de/" target="_blank">www.smart-payment-solutions.de</a>' .
                                                            '<br/><br/>Jetzt die App installieren:',
    'MODULE_PAYMENT_RSMARTSEPA_STR_CHECKOUT_CONFIRMATION' => 'Halten Sie Ihre rSm@rtLITE oder rSm@rtSEPA App bereit. ' .
                                                             'Wenn Sie auf den <b>Bestellen</b> Button klicken, wird ein QR-Code angezeigt, ' .
                                                             'den Sie mit der App scannen und best&auml;tigen m&uuml;ssen.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_ORDERNUMBER' => 'Order Nummer',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SELLER' => 'Verk&auml;ufer',
    'MODULE_PAYMENT_RSMARTSEPA_STR_AMOUNT' => 'Betrag',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SCANTEXT' => 'Starten Sie nun Ihre rSmart-App, dr&uuml;cken Sie bitte auf das Symbol "&Uuml;berweisung" und scannen/fotografieren dann den angezeigten QR-Code',
    'MODULE_PAYMENT_RSMARTSEPA_STR_CANCEL' => 'Abbrechen',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SIMULATEMATCH' => 'Simuliere Erfolg',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SIMULATEFAILURE' => 'Simuliere Fehler',
    'MODULE_PAYMENT_RSMARTSEPA_STR_SIMULATION' => 'Simulation',
    'MODULE_PAYMENT_RSMARTSEPA_STR_ERROR_CREATETRANSACTION' => 'Bezahlung mit rSm@rt fehlgeschlagen!',
    'MODULE_PAYMENT_RSMARTSEPA_STR_REASON' => 'Grund',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYMENTSUCCESS' => 'Bezahlung mit rSm@rt war erfolgreich',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYMENTFAILED' => 'Bezahlung mit rSm@rt ist fehlgeschlagen!',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYMENTCANCELLED' => 'Bezahlung mit rSm@rt wurde abgebrochen!',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PREVIEWLINKTITLE' => 'Vorschau in neuem Browser TAB ohne Javascript Funktionalit&auml;t',
    'MODULE_PAYMENT_RSMARTSEPA_STR_TEMPLATETESTDESCRIPTION' => 'Testen Sie verschiedene Browser Fenstergr&ouml;ssen, um zu sehen, wie sich das Template ver&auml;ndert. Wenn Sie fertig sind, schliessen Sie diese Browser TAB',
    'MODULE_PAYMENT_RSMARTSEPA_STR_TOUCHTEXT1' => 'Falls Sie die rSmartSEPA App installiert haben, bewirkt der Link',
    'MODULE_PAYMENT_RSMARTSEPA_STR_TOUCHTEXT2' => 'den Start dieser App.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_TOUCHTEXT3' => 'Andernfalls wird der Browser versuchen, eine nicht existierende Seite zu &ouml;ffnen.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_TOUCHTEXT4' => 'Wollen Sie diesem Link wirklich folgen?',
    'MODULE_PAYMENT_RSMARTSEPA_STR_INVALID_TERMINALDATA' => 'Ungültige Konfiguration. Grund:',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYSAVEINEUROPE' => 'Realtime, einfach und sicher in ganz Europa bezahlen.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_MATCHFLAGSET' => 'Das MATCH Simulationsflag wurde gesetzt. Der n&auml;chste Pollzyklus wird darauf reagieren.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_FAILUREFLAGSET' => 'Das FEHLER Simulationsflag wurde gesetzt. Der n&auml;chste Pollzyklus wird darauf reagieren.',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYMENTINVALIDHASH' => 'Bezahlung mit rSm@rt wurde wegen eines Fehlers abgebrochen!',
    'MODULE_PAYMENT_RSMARTSEPA_STR_PAYMENTCANCELFAILED' => 'Bezahlvorgang konnte auf dem Server nicht mehr erfolgreich abgebrochen werden!',
    
    'MODULE_PAYMENT_RSMARTSEPA_STATUS_TITLE' => 'rSm@rt',
    'MODULE_PAYMENT_RSMARTSEPA_STATUS_DESC' => 'rSm@rt aktivieren?',
    'MODULE_PAYMENT_RSMARTSEPA_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
    'MODULE_PAYMENT_RSMARTSEPA_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt',
    'MODULE_PAYMENT_RSMARTSEPA_ZONE_TITLE' => 'Bezahlzone',
    'MODULE_PAYMENT_RSMARTSEPA_ZONE_DESC' => 'Wenn du eine Zone ausw&auml;hlst, wird diese Zahlungsart nur dort verf&uuml;gbar sein',
    'MODULE_PAYMENT_RSMARTSEPA_ALLOWED_TITLE' => 'Erlaubte Zonen',
    'MODULE_PAYMENT_RSMARTSEPA_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche f&uuml;r dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_ERROR_TITLE' => 'Bestellstatus nach Fehler bei Bezahlung',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_ERROR_DESC' => 'Status der gesetzt werden soll, wenn die Bezahlung mit einem Fehler beendet wird.<br/><b>Empfohlen: "rsmartsepa Fehler"</b>',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_OK_TITLE' => 'Bestellstatus nach erfolgreicher Bezahlung',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_OK_DESC' => 'Status der gesetzt werden soll, wenn die Bezahlung erfolgreich beendet wird.<br/><b>Empfohlen: "rsmartsepa Bezahlt"</b>',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_TEMP_TITLE' => 'Tempor&auml;rer Bestellstatus',
    'MODULE_PAYMENT_RSMARTSEPA_ORDER_STATUS_ID_TEMP_DESC' => 'Dieser Status wird zu Beginn der Bezahlung gesetzt.<br/><b>Empfohlen: "rsmartsepa Offen"</b>',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_URI_TITLE' => '<hr/><u>TERMINAL DATEN</u><br/><br/>Terminal URI',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_URI_DESC' => 'Diesen Wert findest du in deinem Terminal auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_SELLERID_TITLE' => 'Verk&auml;ufer ID (sellerId)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_SELLERID_DESC' => 'Diesen Wert findest du in deinem Projekt auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_KEY_TITLE' => 'Verk&auml;ufer Key (key)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_KEY_DESC' => 'Diesen Wert findest du in deinem Projekt auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_PROVIDERID_TITLE' => 'Provider ID (providerId)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_PROVIDERID_DESC' => 'Diese ID findest du in deinem Terminal auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_COUNTRYID_TITLE' => 'L&auml;ndercode (countryId)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_COUNTRYID_DESC' => 'Geben Sie hier einen zweistelligen L&auml;ndercode ein. (z.B. de)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_SALESPOINTID_TITLE' => 'Verkaufsstelle (salesPointId)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_SALESPOINTID_DESC' => 'Diesen Wert findest du in deinem Terminal auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_DESCRIPTION_TITLE' => 'Terminalbeschreibung (description)',
    'MODULE_PAYMENT_RSMARTSEPA_TERMINALDATA_DESCRIPTION_DESC' => 'Diesen Wert findest du in deinem Terminal auf dem rSm@rt H&auml;ndler Portal.',
    'MODULE_PAYMENT_RSMARTSEPA_SIMULATIONMODE_TITLE' => '<hr/>Simulationsmodus aktivieren ?',
    'MODULE_PAYMENT_RSMARTSEPA_SIMULATIONMODE_DESC' => 'Der Simulationsmodus dient zum Testen ohne Smartphone. WICHTIG: Die Order wird dennoch entsprechend auf Bezahlt, Fehlgeschlagen oder Abgebrochen gesetzt.',
    'MODULE_PAYMENT_RSMARTSEPA_DEBUGMODE_TITLE' => 'Debug Modus',
    'MODULE_PAYMENT_RSMARTSEPA_DEBUGMODE_DESC' => 'Wenn aktiv, wird ein Javascript Debug Overlay im Bezahl Screen angezeigt',
);
